==> igniteui-angular-charts-18.1.0.tgz: package/esm2015/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DataPieChartToolbarProvider = /*@__PURE__*/ (() => {
    class DataPieChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ad = null;
        }
        g(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.afi != null;
                    }
                    break;
            }
        }
        z(a, b, c, d) {
            let e = a;
            switch (b) {
                case "AngleAxisMajorStroke":
                    this.h("ShowGridlines", 2, a.afi != null);
                    break;
            }
        }
        p(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.afi == null) {
                    if (this.ad != null) {
                        c.afi = this.ad;
                    }
                    else {
                        c.afi = c.dataChart.z6;
                    }
                }
            }
            else {
                if (c.afi != null) {
                    this.ad = c.afi;
                    c.afi = null;
                }
            }
        }
    }
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
})();

==> igniteui-angular-charts-18.1.1.tgz: package/esm2015/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DataPieChartToolbarProvider = /*@__PURE__*/ (() => {
    class DataPieChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ad = null;
        }
        g(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.afu != null;
                    }
                    break;
            }
        }
        z(a, b, c, d) {
            let e = a;
            switch (b) {
                case "AngleAxisMajorStroke":
                    this.h("ShowGridlines", 2, a.afu != null);
                    break;
            }
        }
        p(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.afu == null) {
                    if (this.ad != null) {
                        c.afu = this.ad;
                    }
                    else {
                        c.afu = c.dataChart.z6;
                    }
                }
            }
            else {
                if (c.afu != null) {
                    this.ad = c.afu;
                    c.afu = null;
                }
            }
        }
    }
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
})();
